"""
URL configuration for apibase project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/5.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from django.contrib import admin
from django.urls import path, include
from django.conf import settings
from django.conf.urls.static import static
from drf_spectacular.views import (
    SpectacularAPIView,
    SpectacularRedocView,
    SpectacularSwaggerView,
)

urlpatterns = [
    path("admin/", admin.site.urls),
    path(
        "api/password_reset/",
        include("django_rest_passwordreset.urls", namespace="password_reset"),
    ),
    path("", include("djangopasswordlessknox.urls")),
    # Authentication
    path("api/auth/", include("api.urls")),
    # Devices
    path("api/devices/", include("devices.urls")),
    # Billing
    path("api/billing/", include("billing.urls")),
]
if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
    urlpatterns += (path("api-auth/", include("rest_framework.urls")),)
    urlpatterns += (path("__debug__/", include("debug_toolbar.urls")),)
    urlpatterns += (path("api/schema/", SpectacularAPIView.as_view(), name="schema"),)
    urlpatterns += (
        path(
            "api/swagger/swagger-ui/",
            SpectacularSwaggerView.as_view(),
            name="swagger-ui",
        ),
    )
    urlpatterns += (
        path(
            "api/redoc/", SpectacularRedocView.as_view(url_name="schema"), name="redoc"
        ),
    )
